//===========================================================================
//  $Name: arts++-1-1-a6 $
//  $Id: ArtsBgp4AggregatorAttribute.cc,v 1.7 1999/08/17 20:15:12 dwm Exp $
//===========================================================================
//  CAIDA Copyright Notice
//
//  By accessing this software, arts++, you are duly informed
//  of and agree to be bound by the conditions described below in this
//  notice:
//
//  This software product, arts++, is developed by Daniel W. McRobb, and
//  copyrighted(C) 1998 by the University of California, San Diego
//  (UCSD), with all rights reserved.  UCSD administers the CAIDA grant,
//  NCR-9711092, under which part of this code was developed.
//
//  There is no charge for arts++ software. You can redistribute it
//  and/or modify it under the terms of the GNU General Public License,
//  v.  2 dated June 1991 which is incorporated by reference herein.
//  arts++ is distributed WITHOUT ANY WARRANTY, IMPLIED OR EXPRESS, OF
//  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that the use
//  of it will not infringe on any third party's intellectual property
//  rights.
//
//  You should have received a copy of the GNU GPL along with arts++.
//  Copies can also be obtained from:
//
//    http://www.gnu.org/copyleft/gpl.html
//
//  or by writing to:
//
//    University of California, San Diego
//
//    SDSC/CAIDA
//    9500 Gilman Dr., MS-0505
//    La Jolla, CA 92093 - 0505  USA
//
//  Or contact:
//
//    info@caida.org
//===========================================================================

#include <string>

#include "ArtsPrimitive.hh"
#include "ArtsBgp4AggregatorAttribute.hh"

static const string rcsid = "@(#) $Name: arts++-1-1-a6 $ $Id: ArtsBgp4AggregatorAttribute.cc,v 1.7 1999/08/17 20:15:12 dwm Exp $";

//----------------------------------------------------------------------------
//        ArtsBgp4AggregatorAttribute::ArtsBgp4AggregatorAttribute()       
//............................................................................
//  
//----------------------------------------------------------------------------
ArtsBgp4AggregatorAttribute::ArtsBgp4AggregatorAttribute()
{
  this->_AS = 0;
  this->_ipAddr = 0;

  #ifndef NDEBUG
    ++this->_numObjects;
  #endif
}

//----------------------------------------------------------------------------
//  ArtsBgp4AggregatorAttribute:: 
//  ArtsBgp4AggregatorAttribute(const ArtsBgp4AggregatorAttribute & aggAttr) 
//............................................................................
//  
//----------------------------------------------------------------------------
ArtsBgp4AggregatorAttribute::
ArtsBgp4AggregatorAttribute(const ArtsBgp4AggregatorAttribute & aggAttr)
{
  this->AS(aggAttr.AS());
  this->IpAddr(aggAttr.IpAddr());
}

//----------------------------------------------------------------------------
//       ArtsBgp4AggregatorAttribute::~ArtsBgp4AggregatorAttribute()       
//............................................................................
//  
//----------------------------------------------------------------------------
ArtsBgp4AggregatorAttribute::~ArtsBgp4AggregatorAttribute()
{
  #ifndef NDEBUG
    --this->_numObjects;
  #endif
}

//-------------------------------------------------------------------------
//           uint16_t ArtsBgp4AggregatorAttribute::AS() const            
//.........................................................................
//                                                                         
//-------------------------------------------------------------------------
uint16_t ArtsBgp4AggregatorAttribute::AS() const
{
  return(this->_AS);
}

//-------------------------------------------------------------------------
//         uint16_t ArtsBgp4AggregatorAttribute::AS(uint16_t as)         
//.........................................................................
//                                                                         
//-------------------------------------------------------------------------
uint16_t ArtsBgp4AggregatorAttribute::AS(uint16_t as)
{
  this->_AS = as;
  return(this->_AS);
}

//----------------------------------------------------------------------------
//         ipv4addr_t & ArtsBgp4AggregatorAttribute::IpAddr() const        
//............................................................................
//  
//----------------------------------------------------------------------------
const ipv4addr_t & ArtsBgp4AggregatorAttribute::IpAddr() const
{
  return(this->_ipAddr);
}

//----------------------------------------------------------------------------
//        const ipv4addr_t &
//        ArtsBgp4AggregatorAttribute::IpAddr(ipv4addr_t & ipAddr)  
//............................................................................
//  
//----------------------------------------------------------------------------
const ipv4addr_t &
ArtsBgp4AggregatorAttribute::IpAddr(const ipv4addr_t & ipAddr)
{
  this->_ipAddr = ipAddr;
  return(this->_ipAddr);
}

//-------------------------------------------------------------------------
// ArtsBgp4AggregatorAttribute &                      
// ArtsBgp4AggregatorAttribute::operator = (const ArtsBgp4AggregatorAttribute &
//                                          aggregator) 
//.........................................................................
//                                                                         
//-------------------------------------------------------------------------
ArtsBgp4AggregatorAttribute &
ArtsBgp4AggregatorAttribute::operator = (const ArtsBgp4AggregatorAttribute &
                                         aggregator)
{
  this->AS(aggregator.AS());
  this->IpAddr(aggregator.IpAddr());
  return(*this);
}

//----------------------------------------------------------------------------
//        istream & ArtsBgp4AggregatorAttribute::read(istream & is,        
//                                                    uint8_t version = 0) 
//............................................................................
//  
//----------------------------------------------------------------------------
istream & ArtsBgp4AggregatorAttribute::read(istream & is,
                                            uint8_t version = 0)
{
  g_ArtsLibInternal_Primitive.ReadUint16(is,this->_AS,sizeof(this->_AS));
  is.read(&this->_ipAddr,sizeof(this->_ipAddr));
  return(is);
}

//----------------------------------------------------------------------------
//    int ArtsBgp4AggregatorAttribute::read(int fd, uint8_t version = 0)   
//............................................................................
//  
//----------------------------------------------------------------------------
int ArtsBgp4AggregatorAttribute::read(int fd, uint8_t version = 0)
{
  int  rc;
  int  bytesRead = 0;
  
  rc = g_ArtsLibInternal_Primitive.ReadUint16(fd,this->_AS,sizeof(this->_AS));
  if (rc < sizeof(this->_AS))
    return(-1);
  bytesRead += rc;
  rc = g_ArtsLibInternal_Primitive.ReadIpv4Network(fd,this->_ipAddr,
                                                   sizeof(this->_ipAddr));
  if (rc < sizeof(this->_ipAddr))
    return(-1);
  bytesRead += rc;
  return(bytesRead);
}

//---------------------------------------------------------------------------
//  ostream & ArtsBgp4AggregatorAttribute::write(ostream & os,
//                                               uint8_t version = 0) const
//............................................................................
//
//----------------------------------------------------------------------------
ostream & ArtsBgp4AggregatorAttribute::write(ostream & os,
                                             uint8_t version = 0) const
{
  g_ArtsLibInternal_Primitive.WriteUint16(os,this->_AS,sizeof(this->_AS));
  os.write(&this->_ipAddr,sizeof(this->_ipAddr));
  return(os);
}

//----------------------------------------------------------------------------
// int ArtsBgp4AggregatorAttribute::write(int fd, uint8_t version = 0) const 
//............................................................................
//  
//----------------------------------------------------------------------------
int ArtsBgp4AggregatorAttribute::write(int fd, uint8_t version = 0) const
{
  int  rc;
  int  bytesWritten = 0;

  rc = g_ArtsLibInternal_Primitive.WriteUint16(fd,this->_AS,
                                               sizeof(this->_AS));
  if (rc < sizeof(this->_AS))
    return(-1);
  bytesWritten += rc;
  rc = g_ArtsLibInternal_Primitive.WriteIpv4Network(fd,this->_ipAddr,
                                                    sizeof(this->_ipAddr));
  if (rc < sizeof(this->_ipAddr))
    return(-1);
  bytesWritten += rc;
  return(bytesWritten);
}

//----------------------------------------------------------------------------
// uint32_t ArtsBgp4AggregatorAttribute::Length(uint8_t version = 0) const 
//............................................................................
//  
//----------------------------------------------------------------------------
uint32_t ArtsBgp4AggregatorAttribute::Length(uint8_t version = 0) const
{
  return(sizeof(this->_AS) + sizeof(this->_ipAddr));
}

uint32_t ArtsBgp4AggregatorAttribute::_numObjects = 0;
