//===========================================================================
//  @(#) $Name: arts++-1-1-a6 $
//  @(#) $Id: ArtsIpPath.cc,v 1.5 1999/04/13 01:35:32 dwm Exp $
//===========================================================================
//  CAIDA Copyright Notice
//
//  By accessing this software, arts++, you are duly informed
//  of and agree to be bound by the conditions described below in this
//  notice:
//
//  This software product, arts++, is developed by Daniel W. McRobb, and
//  copyrighted(C) 1998 by the University of California, San Diego
//  (UCSD), with all rights reserved.  UCSD administers the CAIDA grant,
//  NCR-9711092, under which part of this code was developed.
//
//  There is no charge for arts++ software. You can redistribute it
//  and/or modify it under the terms of the GNU General Public License,
//  v.  2 dated June 1991 which is incorporated by reference herein.
//  arts++ is distributed WITHOUT ANY WARRANTY, IMPLIED OR EXPRESS, OF
//  MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE or that the use
//  of it will not infringe on any third party's intellectual property
//  rights.
//
//  You should have received a copy of the GNU GPL along with arts++.
//  Copies can also be obtained from:
//
//    http://www.gnu.org/copyleft/gpl.html
//
//  or by writing to:
//
//    University of California, San Diego
//
//    SDSC/CAIDA
//    9500 Gilman Dr., MS-0505
//    La Jolla, CA 92093 - 0505  USA
//
//  Or contact:
//
//    info@caida.org
//===========================================================================

#include <string>
#include <algorithm>

#include "Arts.hh"
#include "ArtsIpPath.hh"

static const string rcsid = "@(#) $Name: arts++-1-1-a6 $ $Id: ArtsIpPath.cc,v 1.5 1999/04/13 01:35:32 dwm Exp $";

//-------------------------------------------------------------------------
//          ArtsIpPath::ArtsIpPath(ipv4addr_t src, ipv4addr_t dst)         
//.........................................................................
//                                                                         
//-------------------------------------------------------------------------
ArtsIpPath::ArtsIpPath(ipv4addr_t src, ipv4addr_t dst)
{
  this->Header().Identifier(artsC_OBJECT_IP_PATH);
  this->_data._ipPath = new ArtsIpPathData();
  this->IpPathData()->Src(src);
  this->IpPathData()->Dst(dst);
}

//-------------------------------------------------------------------------
//          ArtsIpPath::ArtsIpPath(const ArtsIpPath & artsIpPath)          
//.........................................................................
//                                                                         
//-------------------------------------------------------------------------
ArtsIpPath::ArtsIpPath(const ArtsIpPath & artsIpPath) 
{
  this->_header = artsIpPath.Header();
  this->_attributes = artsIpPath.Attributes();
  this->_data._ipPath = new ArtsIpPathData();
  *(this->_data._ipPath) = *(artsIpPath.IpPathData());
}

//-------------------------------------------------------------------------
//                         ArtsIpPath::ArtsIpPath()                        
//.........................................................................
//                                                                         
//-------------------------------------------------------------------------
ArtsIpPath::ArtsIpPath()
{
  this->Header().Identifier(artsC_OBJECT_IP_PATH);
  this->_data._ipPath = new ArtsIpPathData();
  this->IpPathData()->Dst(0);
}

//-------------------------------------------------------------------------
//                        ArtsIpPath::~ArtsIpPath()                        
//.........................................................................
//                                                                         
//-------------------------------------------------------------------------
ArtsIpPath::~ArtsIpPath()
{
}

//----------------------------------------------------------------------------
//      istream & operator >> (istream & is, ArtsIpPath & artsIpPath) 
//............................................................................
//  
//----------------------------------------------------------------------------
istream & operator >> (istream & is, ArtsIpPath & artsIpPath)
{
  streampos   streamPosition;
  ArtsHeader  artsHeader;

  //  save our stream position
  streamPosition = is.tellg();

  //  read the object header
  artsHeader.read(is);
  if (is.eof()) {
    return(is);
  }

  //  skip over objects that are not IP path objects
  while (artsHeader.Identifier() != artsC_OBJECT_IP_PATH) {
    is.seekg(artsHeader.AttrLength() + artsHeader.DataLength(),ios::cur);
    streamPosition = is.tellg();
    artsHeader.read(is);
    if (is.eof()) {
      break;
    }
  }

  //  if we reached the end of the file before finding an IP path object,
  //  just return the istream and don't touch artsIpPath
  if (is.eof()) {
    return(is);
  }

  //  back up to the start os the header and read the entire IP path
  //  object, then return the istream.
  is.seekg(streamPosition,ios::beg);
  artsIpPath.read(is);
  return(is);
}
  

